from distutils.core import setup
setup(name='test_vivian_foo_embedway',
      version='1.0',
      py_modules=['foo'],
      author='vivianzhou',
      author_email='18602755192@163.com',
      url='http://www.baidu.com',
      )
